@@ -1,39 +1,46 @@
 `superSubset` <-
-function(mydata, outcome = "", neg.out = FALSE, conditions = c(""), relation = "necessity",
+function(data, outcome = "", neg.out = FALSE, conditions = c(""), relation = "necessity",
          incl.cut = 1, cov.cut = 0, use.tilde = FALSE, use.letters = FALSE) {
     
     memcare <- FALSE # to be updated with a future version
     
     incl.cut <- incl.cut - .Machine$double.eps ^ 0.5
-    cov.cut <- cov.cut - ifelse(cov.cut > 0, .Machine$double.eps ^ 0.5, 0)
+    if (cov.cut > 0) {
+        cov.cut <- cov.cut - .Machine$double.eps ^ 0.5
+    }
     
     if (all(conditions == c(""))) {
-        conditions <- names(mydata)[-which(names(mydata) == outcome)]
+        conditions <- names(data)[-which(names(data) == outcome)]
     }
     
-    verify.data(mydata, outcome, conditions)
+    verify.data(data, outcome, conditions)
     
-    if (!relation %in% c("necessity", "sufficiency")) {
-        stop("\nThe relationship should be either \"necessity\" or \"sufficiency\".\n\n", call. = FALSE)
+    if (!relation %in% c("necessity", "sufficiency", "nec", "suf", "necsuf")) {
+        stop("\nThe relationship should be either \"necessity\", \"sufficiency\" or \"necsuf\".\n\n", call. = FALSE)
     }
     
-    colnames(mydata) <- toupper(colnames(mydata))
+    relationcopy <- relation
+    if (relation == "necsuf") {
+        relation <- "necessity"
+    }
+    
+    colnames(data) <- toupper(colnames(data))
     conditions <- replacements <- toupper(conditions)
     outcome <- toupper(outcome)
     
-    mydata <- mydata[, c(conditions, outcome)]
+    data <- data[, c(conditions, outcome)]
     nofconditions <- length(conditions)
     
     
     if (neg.out) {
-        mydata[, outcome] <- 1 - mydata[, outcome]
+        data[, outcome] <- 1 - data[, outcome]
     }
     
     uplow <- !use.tilde
     
-    fc <- apply(mydata[, conditions], 2, function(x) any(x %% 1 > 0))
+    fc <- apply(data[, conditions], 2, function(x) any(x %% 1 > 0))
     
-    if (mv.data <- any(mydata[, conditions] > 1)) {
+    if (mv.data <- any(data[, conditions] > 1)) {
         uplow <- use.tilde <- FALSE
     }
     
@@ -44,40 +51,39 @@ function(mydata, outcome = "", neg.out = FALSE, conditions = c(""), relation = "
     if (use.letters & !alreadyletters) {
         replacements <- LETTERS[seq(length(conditions))]
         names(replacements) <- conditions
-        colnames(mydata)[seq(length(conditions))] <- conditions <- replacements
+        colnames(data)[seq(length(conditions))] <- conditions <- replacements
         collapse <- ifelse(!uplow | use.tilde, "*", "")
     }
     
-    noflevels <- apply(mydata[, conditions], 2, max) + 1
+    noflevels <- apply(data[, conditions], 2, max) + 1
     noflevels[fc] <- 2
     mbase <- c(rev(cumprod(rev(noflevels + 1))), 1)[-1]
     
     
     if (memcare) {
-        CMatrix <- .Call("superSubsetMem", as.matrix(mydata[, conditions]), noflevels, mbase, fc, mydata[, outcome], relation == "necessity", package="QCA")
+        CMatrix <- .Call("superSubsetMem", as.matrix(data[, conditions]), noflevels, mbase, as.numeric(fc), data[, outcome], relation == "necessity", PACKAGE="QCA")
     }
     else {
         nk <- createMatrix(noflevels + 1)
         colnames(nk) <- conditions
         nk <- nk[-1, ] # first row is always empty
         
-        CMatrix <- .Call("superSubset", as.matrix(mydata[, conditions]), nk, fc, mydata[, outcome], relation == "necessity", package="QCA")
+        CMatrix <- .Call("superSubset", as.matrix(data[, conditions]), nk, as.numeric(fc), data[, outcome], as.numeric(relation == "necessity"), PACKAGE="QCA")
     }
     
+    
+    # to modify this, attributing colnames copies the object and uses too much memory
     expressions <- colnames(CMatrix) <- seq_len(ncol(CMatrix)) + 1 # plus 1 because the first row of the nk matrix was deleted
-    lincl <- ifelse(relation == "necessity", 2, 1)
+    lincl <- ifelse(relation %in% c("necessity", "nec"), 2, 1)
     
     expressions <- expressions[CMatrix[lincl, ] >= incl.cut & CMatrix[3 - lincl, ] >= cov.cut]
     
     prev.result <- FALSE
     lexpressions <- length(expressions)
+    
     if (lexpressions > 0) {
-        if (relation == "sufficiency") {
-            # expressions <- .Call("removeRedundants", expressions, noflevels, mbase, package="QCA")
-            index <- 0
-            while((index <- index + 1) < length(expressions)) {
-                expressions <- expressions[is.na(match(expressions, .Call("findSubsets", expressions[index], noflevels, mbase, max(expressions), package="QCA")))]
-            }
+        if (relation %in% c("sufficiency", "suf")) {
+            expressions <- .Call("removeRedundants", expressions, noflevels, mbase, PACKAGE="QCA")
         }
         
         result.matrix <- getRow(noflevels + 1, expressions)
@@ -97,21 +103,16 @@ function(mydata, outcome = "", neg.out = FALSE, conditions = c(""), relation = "
     }
     
     lexprnec <- 0
-    if (relation == "necessity") {
+    if (relation  %in% c("necessity", "nec")) {
         exprnec <- seq_len(ncol(CMatrix)) + 1
         
         exprnec <- exprnec[CMatrix[4, ] >= incl.cut & CMatrix[3, ] >= cov.cut]
         
-        # exprnec <- .Call("removeRedundants", exprnec, noflevels, mbase, package="QCA")
-        index <- 0 # !!!!!!!!!!!!!!
-        while((index <- index + 1) < length(exprnec)) {
-            exprnec <- exprnec[is.na(match(exprnec, .Call("findSubsets", exprnec[index], noflevels, mbase, max(exprnec), package="QCA")))]
-        }
+        exprnec <- .Call("removeRedundants", exprnec, noflevels, mbase, PACKAGE="QCA")
         
         exprnec <- setdiff(exprnec, expressions)
         lexprnec <- length(exprnec)
         
-        
         if (lexprnec + lexpressions == 0) {
             stop("\nThere are no combinations that match given criteria.\n\n", call. = FALSE)
         }
@@ -153,9 +154,9 @@ function(mydata, outcome = "", neg.out = FALSE, conditions = c(""), relation = "
     }
     
     
-    mins <- matrix(NA, nrow=nrow(mydata), ncol=nrow(result.matrix))
+    mins <- matrix(NA, nrow=nrow(data), ncol=nrow(result.matrix))
     for (i in seq(nrow(result.matrix))) {
-        mins[, i] <- apply(mydata[, conditions], 1, function(v) {
+        mins[, i] <- apply(data[, conditions], 1, function(v) {
             e <- result.matrix[i, , drop=FALSE]
             if (any(ox <- e[fc] == 1)) {
                 v[fc][ox] <- 1 - v[fc][ox]
@@ -175,8 +176,13 @@ function(mydata, outcome = "", neg.out = FALSE, conditions = c(""), relation = "
     }
     
     colnames(mins) <- rownames(result)
-    rownames(mins) <- rownames(mydata)
+    rownames(mins) <- rownames(data)
     mins <- as.data.frame(mins)
+    
+    if (relationcopy == "necsuf") {
+        colnames(result) <- c("inclN", "PRI", "inclS")
+    }
+    
     return(structure(list(incl.cov=result, coms=mins, use.letters=use.letters, letters=replacements), class="ss"))
 }
 
